@@ -22,8 +22,8 @@ pub mod camera;
 pub use self::camera::Camera;
 pub mod camera_request;
 pub use self::camera_request::CameraRequest;
-pub mod camera_type_enum;
-pub use self::camera_type_enum::CameraTypeEnum;
+pub mod camera_type;
+pub use self::camera_type::CameraType;
 pub mod cloudiot_device;
 pub use self::cloudiot_device::CloudiotDevice;
 pub mod cloudiot_device_request;
@@ -62,8 +62,6 @@ pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
 pub mod license;
 pub use self::license::License;
-pub mod license_credentials;
-pub use self::license_credentials::LicenseCredentials;
 pub mod license_request;
 pub use self::license_request::LicenseRequest;
 pub mod mobile_auth_request;
@@ -214,6 +212,8 @@ pub mod print_job_event_request;
 pub use self::print_job_event_request::PrintJobEventRequest;
 pub mod print_job_event_type;
 pub use self::print_job_event_type::PrintJobEventType;
+pub mod print_nanny_api_config;
+pub use self::print_nanny_api_config::PrintNannyApiConfig;
 pub mod print_nanny_plugin_event;
 pub use self::print_nanny_plugin_event::PrintNannyPluginEvent;
 pub mod print_nanny_plugin_event_event_type_enum;
